@@ -20,8 +20,8 @@
 #' This is a generic function to append confidence intervals for
 #' predictions of a model fit to a data frame. A confidence interval
 #' is generated for the fitted value of each observation in
-#' \code{tb}. These confidence intervals are then appended to
-#' \code{tb} and returned to the user as a tibble. The \code{fit} may
+#' \code{df}. These confidence intervals are then appended to
+#' \code{df} and returned to the user as a data frame. The \code{fit} may
 #' be a linear, log-linear, linear mixed, generalized linear model,
 #' generalized linear mixed, or accelerated failure time model.
 #'
@@ -42,9 +42,8 @@
 #'
 #' @import stats
 #' @import lme4
-#' @importFrom magrittr %>%
+#' @importFrom dplyr %>%
 #' @importFrom dplyr bind_rows
-#' @importFrom tibble as_data_frame
 #' @importFrom arm se.ranef
 #' @importFrom arm sim
 #' @importFrom MASS rnegbin
@@ -55,7 +54,7 @@
 #' @importFrom boot boot.ci
 #' @importFrom utils packageVersion
 #'
-#' @param tb A tibble or data frame of new data. \code{tb} can be the
+#' @param df A data frame of new data. \code{df} can be the
 #'     original data or new data.
 #' @param fit An object of class \code{lm}, \code{glm},
 #'     \code{lmerMod}, \code{glmerMod}, or \code{survreg}. Predictions
@@ -68,9 +67,9 @@
 #'     named \code{names[1]} and the upper confidence bound will be
 #'     named \code{names[2]}.
 #' @param yhatName A character vector of length one. Name of the
-#'     vector of the predictions made for each observation in \code{tb}
+#'     vector of the predictions made for each observation in \code{df}
 #' @param ... Additional arguments.
-#' @return A tibble, \code{tb}, with predicted values, upper and lower
+#' @return A dataframe, \code{df}, with predicted values, upper and lower
 #'     confidence bounds attached.
 #'
 #' @examples
@@ -108,6 +107,6 @@
 #'
 #' @export
 
-add_ci <- function(tb, fit, alpha = 0.05, names = NULL, yhatName = "pred", ...){
+add_ci <- function(df, fit, alpha = 0.05, names = NULL, yhatName = "pred", ...){
     UseMethod("add_ci", fit)
 }
