@@ -26,7 +26,7 @@
 #' response level. Alternatively, confidence intervals may be
 #' calculated through a nonparametric bootstrap method.
 #'
-#' @param tb A tibble or data frame of new data.
+#' @param df A data frame of new data.
 #' @param fit An object of class \code{glm}.
 #' @param alpha A real number between 0 and 1. Controls the confidence
 #'     level of the interval estimates.
@@ -36,7 +36,7 @@
 #'     named \code{names[1]} and the upper confidence bound will be
 #'     named \code{names[2]}.
 #' @param yhatName A character vector of length one. Name of the
-#'     vector of predictions made for each observation in tb
+#'     vector of predictions made for each observation in df
 #' @param type A character vector of length one. Must be \code{type =
 #'     "parametric"} or \code{type = "boot"}. \code{type} determines
 #'     the method used to compute the confidence intervals.
@@ -48,7 +48,7 @@
 #'     bootstrap method is used.
 #' @param ... Additional arguments.
 #'
-#' @return A tibble, \code{tb}, with predicted values, upper and lower
+#' @return A dataframe, \code{df}, with predicted values, upper and lower
 #'     confidence bounds attached.
 #'
 #' @seealso \code{\link{add_pi.glm}} for prediction intervals for
@@ -81,7 +81,7 @@
 #'
 #' @export
 
-add_ci.glm <- function(tb, fit, alpha = 0.05, names = NULL, yhatName = "pred",
+add_ci.glm <- function(df, fit, alpha = 0.05, names = NULL, yhatName = "pred",
                        response = TRUE, type = "parametric", nSims = 2000, ...){
 
     if (!(fit$converged))
@@ -90,21 +90,21 @@ add_ci.glm <- function(tb, fit, alpha = 0.05, names = NULL, yhatName = "pred",
         names[1] <- paste("LCB", alpha/2, sep = "")
         names[2] <- paste("UCB", 1 - alpha/2, sep = "")
     }
-    if ((names[1] %in% colnames(tb))) {
+    if ((names[1] %in% colnames(df))) {
         warning ("These CIs may have already been appended to your dataframe. Overwriting.")
     }
 
     if (type == "boot")
-        boot_ci_glm(tb, fit, alpha, names, yhatName, response, nSims)
+        boot_ci_glm(df, fit, alpha, names, yhatName, response, nSims)
     else if (type == "parametric")
-        parametric_ci_glm(tb, fit, alpha, names, yhatName, response)
+        parametric_ci_glm(df, fit, alpha, names, yhatName, response)
     else
         stop("Incorrect interval type specified!")
 
 }
 
-parametric_ci_glm <- function(tb, fit, alpha, names, yhatName, response){
-    out <- predict(fit, tb, se.fit = TRUE, type = "link")
+parametric_ci_glm <- function(df, fit, alpha, names, yhatName, response){
+    out <- predict(fit, df, se.fit = TRUE, type = "link")
 
     if (fit$family$family %in% c("binomial", "poisson"))
         crit_val <- qnorm(p = 1 - alpha/2, mean = 0, sd = 1)
@@ -130,22 +130,22 @@ parametric_ci_glm <- function(tb, fit, alpha, names, yhatName, response){
         pred <- out$fit
     }
 
-    if(is.null(tb[[yhatName]]))
-        tb[[yhatName]] <- pred
-    tb[[names[1]]] <- lwr
-    tb[[names[2]]] <- upr
-    tibble::as_data_frame(tb)
+    if(is.null(df[[yhatName]]))
+        df[[yhatName]] <- pred
+    df[[names[1]]] <- lwr
+    df[[names[2]]] <- upr
+    data.frame(df)
 }
 
-boot_fit <- function(data, tb, fit, lvl, indices){
+boot_fit <- function(data, df, fit, lvl, indices){
     data_temp <- data[indices,]
     form <- fit$formula
     fam <- fit$family
     temp_fit <- glm(form, data = data_temp, family = fam)
-    predict(temp_fit, newdata = tb, type = lvl)
+    predict(temp_fit, newdata = df, type = lvl)
 }
 
-boot_ci_glm <- function(tb, fit, alpha, names, yhatName, response, nSims){
+boot_ci_glm <- function(df, fit, alpha, names, yhatName, response, nSims){
     if (response){
         lvl <- "response"
     }
@@ -153,18 +153,18 @@ boot_ci_glm <- function(tb, fit, alpha, names, yhatName, response, nSims){
         lvl <- "link"
     }
 
-    out <- predict(fit, tb, type = lvl)
+    out <- predict(fit, df, type = lvl)
 
     boot_obj <- boot(data = fit$model,
                      statistic = boot_fit,
                      R = nSims,
                      fit = fit,
                      lvl = lvl,
-                     tb = tb)
+                     df = df)
 
-    temp_mat <- matrix(0, ncol = 2, nrow = NROW(tb))
+    temp_mat <- matrix(0, ncol = 2, nrow = NROW(df))
 
-    for (i in 1:NROW(tb)){
+    for (i in 1:NROW(df)){
         temp_mat[i,] <- boot.ci(boot_obj,
                                 type = "bca",
                                 conf = 1 - alpha,
@@ -178,9 +178,9 @@ boot_ci_glm <- function(tb, fit, alpha, names, yhatName, response, nSims){
     ## lwr <- apply(raw_boot, 2, FUN = quantile, probs = alpha / 2)
     ## upr <- apply(raw_boot, 2, FUN = quantile, probs = 1 - alpha / 2)
 
-    if(is.null(tb[[yhatName]]))
-        tb[[yhatName]] <- out
-    tb[[names[1]]] <- lwr
-    tb[[names[2]]] <- upr
-    tibble::as_data_frame(tb)
+    if(is.null(df[[yhatName]]))
+        df[[yhatName]] <- out
+    df[[names[1]]] <- lwr
+    df[[names[2]]] <- upr
+    data.frame(df)
 }
