@@ -36,7 +36,7 @@
 #' Quantiles of the simulated responses are taken at the end to
 #' produce intervals of the desired level.
 #'
-#' @param tb A tibble or data frame of new data.
+#' @param df A data frame of new data.
 #' @param fit An object of class \code{negbin}.
 #' @param alpha A real number between 0 and 1. Controls the confidence
 #'     level of the interval estimates.
@@ -50,7 +50,7 @@
 #'     simulations to run.
 #' @param ... Additional arguments.
 #'
-#' @return A tibble, \code{tb}, with predicted values, upper and lower
+#' @return A dataframe, \code{df}, with predicted values, upper and lower
 #'     prediction bounds attached.
 #'
 #' @seealso \code{\link{add_ci.negbin}} for confidence intervals for
@@ -69,33 +69,33 @@
 #' @export
 
 
-add_pi.negbin <- function(tb, fit, alpha = 0.05, names = NULL, yhatName = "pred",
+add_pi.negbin <- function(df, fit, alpha = 0.05, names = NULL, yhatName = "pred",
                           nSims = 2000, ...){
 
     if (is.null(names)) {
         names[1] <- paste("LPB", alpha/2, sep = "")
         names[2] <- paste("UPB", 1 - alpha/2, sep = "")
     }
-    if ((names[1] %in% colnames(tb)))
+    if ((names[1] %in% colnames(df)))
         warning ("These PIs may have already been appended to your dataframe. Overwriting.")
 
-    sim_pi_negbin(tb, fit, alpha, names, yhatName, nSims)
+    sim_pi_negbin(df, fit, alpha, names, yhatName, nSims)
 }
 
 
-sim_pi_negbin <- function(tb, fit, alpha, names, yhatName, nSims){
-    out <- predict(fit, newdata = tb, type = "response")
+sim_pi_negbin <- function(df, fit, alpha, names, yhatName, nSims){
+    out <- predict(fit, newdata = df, type = "response")
     disp <- fit$dispersion
-    sim_response <- get_sim_response_nb(tb, fit, nSims)
+    sim_response <- get_sim_response_nb(df, fit, nSims)
 
     lwr <- apply(sim_response, 1, FUN = quantile, probs = alpha/2, type = 1)
     upr <- apply(sim_response, 1, FUN = quantile, probs = 1 - alpha / 2, type = 1)
 
-    if(is.null(tb[[yhatName]]))
-        tb[[yhatName]] <- out
-    tb[[names[1]]] <- lwr
-    tb[[names[2]]] <- upr
-    tibble::as_data_frame(tb)
+    if(is.null(df[[yhatName]]))
+        df[[yhatName]] <- out
+    df[[names[1]]] <- lwr
+    df[[names[2]]] <- upr
+    data.frame(df)
 
 }
 
@@ -129,9 +129,9 @@ get_negbin_sims <- function(fit, nSims) {
 }
 
 ## link get_sim_response, but only for negative binomial model
-get_sim_response_nb <- function(tb, fit, nSims){
-    nPreds <- NROW(tb)
-    modmat <- model.matrix(fit, data = tb)
+get_sim_response_nb <- function(df, fit, nSims){
+    nPreds <- NROW(df)
+    modmat <- model.matrix(fit, data = df)
     response_distr <- fit$family$family
     inverselink <- fit$family$linkinv
     sims <- get_negbin_sims(fit, nSims)
